init_fdt

Function init_fdt 

pub fn init_fdt(addr: usize)
Initializes the FDT subsystem with the given address.

Arguments

  • addr: The address of the FDT.

Safety

This function modifies a static variable that holds the FDT address. Ensure that this function is called before any other FDT-related functions to avoid undefined behavior.