pub fn init_fdt(addr: usize)
Initializes the FDT subsystem with the given address.
addr
This function modifies a static variable that holds the FDT address. Ensure that this function is called before any other FDT-related functions to avoid undefined behavior.